==> nextcloud-27.1.3.tgz: nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentaires",
    "You commented" : "Vous avez commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui depuis a été supprimé",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vous a mentionné dans un commentaire sur \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "Cancel edit" : "Annuler les modifications",
    "Post comment" : "Publier le commentaire",
    "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker" : "\"@\" pour les mentions, \":\" pour les émojis, \"/\" pour le sélecteur intelligent",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "No more messages" : "Aucun autre message",
    "Retry" : "Réessayer",
    "Failed to mark comments as read" : "Les commentaires n'ont pas été marqués comme lus",
    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
    "_1 new comment_::_{unread} new comments_" : ["1 nouveau commentaire","{unread} nouveaux commentaires","{unread} nouveaux commentaires"],
    "Comment" : "Commenter",
    "An error occurred while trying to edit the comment" : "Une erreur s'est produite lors de la tentative de modification du commentaire",
    "Comment deleted" : "Commentaire supprimé",
    "An error occurred while trying to delete the comment" : "Une erreur s'est produite lors de la tentative de suppression du commentaire",
    "An error occurred while trying to create the comment" : "Une erreur s'est produite lors de la tentative de création du commentaire",
    "%1$s commented" : "%1$s a commenté",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus","%n commentaires non lus"]
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.5.tgz: nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentaires",
    "You commented" : "Vous avez commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui depuis a été supprimé",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vous a mentionné dans un commentaire sur \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "Cancel edit" : "Annuler les modifications",
    "Post comment" : "Publier le commentaire",
    "@ for mentions, : for emoji, / for smart picker" : "@ pour les mentions, : pour les émojis, / pour le sélecteur intelligent",
    "Could not reload comments" : "Impossible de rafraichir les commentaires",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "No more messages" : "Aucun autre message",
    "Retry" : "Réessayer",
    "Failed to mark comments as read" : "Les commentaires n'ont pas été marqués comme lus",
    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
    "_1 new comment_::_{unread} new comments_" : ["1 nouveau commentaire","{unread} nouveaux commentaires","{unread} nouveaux commentaires"],
    "Comment" : "Commenter",
    "An error occurred while trying to edit the comment" : "Une erreur s'est produite lors de la tentative de modification du commentaire",
    "Comment deleted" : "Commentaire supprimé",
    "An error occurred while trying to delete the comment" : "Une erreur s'est produite lors de la tentative de suppression du commentaire",
    "An error occurred while trying to create the comment" : "Une erreur s'est produite lors de la tentative de création du commentaire",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus","%n commentaires non lus"]
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
